---
title: A Brief Guide to Getting Started in the Fediverse
description: As the title says, this guide helps get started in the Fediverse by introducing some key concepts, then explains how to get an account, before finally covering how to find good accounts to follow.
date_pub: 2018-07-04T04:14:00-04:00
date_upd: 2018-10-26T17:22:00-04:00
content_type: formatted
short_code: gd
---

## A Brief Guide to Getting Started in the Fediverse

I've only been active in the Fediverse since February, but I've become so excited by the idea of it that I've made it my mission to help other people get online. The first step in this, for me, is to get several of my family and friends on the Fediverse, and I figured that it might be useful to have a document to help them figure out where to go after they sign up. This is that document.

But first, a few quick terms.

<a href="#" class="topLink">[ Back to Top ]</a>

### Fediverse Terms

+ **The Fediverse** - A network of different decentralized social media application instances (web sites with special capabilities) which communicate with each other via one or more protocols (ActivityPub, OStatus, etc). Anyone with enough tech savy can run one of these applications on a server, creating a new instance, and expanding the Fediverse. Some instances are public, allowing anyone to join, while others are private, limited only to a specific group of people (or sometimes just a single person). Some the applications used to make up the Fediverse include...
  + **[Mastodon](https://joinmastodon.org/)** - The most popular decentralized social media application by far (AFAIK). Features a [Tweetdeck](https://en.wikipedia.org/wiki/TweetDeck)-like, multi-column interface.
  + **[Pleroma](https://pleroma.social/)** - Another decentralized social media application which is a little different from Mastodon, but still speaks the same protocols, allowing them to interact with each other. Pleroma is a significantly more lightweight application than Mastodon, and can actually be run on [an old computer in your house](/images/server_pic.jpg) (if you're willing and able to put the time into learning how).
  + **[PeerTube](https://joinpeertube.org/)** - A relatively new application which aims to give a YouTube-like experience while using [peer-to-peer](https://en.wikipedia.org/wiki/Peer-to-peer) sharing to cut down on video hosting costs.
  + Other applications include **[PixelFed](https://pixelfed.org/)**, **[Friendica](https://friendi.ca/)** and **[Hubzilla](https://start.hubzilla.org/)**.
<a id="birdsite" style="visibility: hidden"></a>
+ **Birdsite** - Another word for Twitter.
+ **Front-Ends** - One of the more interesting things about using the ActivityPub protocol is that it allows for developers to write applications that can support any ActivityPub server, not just a specific instance (or even a specific application). For example, most Pleroma instances also host copies of the Mastodon front-end, for people that prefer its [Tweetdeck](https://en.wikipedia.org/wiki/TweetDeck)-like interface. Other available front-ends include:
  + [Pinafore](https://pinafore.social/), a most excellent (IMHO) web front-end that allows for a single user to manage multiple accounts (even on mobile).
  + [Brutaldon](https://github.com/jfmcbrayer/brutaldon), a web front-end which supports terminal-based browsers like [Lynx](https://en.wikipedia.org/wiki/Lynx_(web_browser)).
  + Or, if you'd prefer, you can choose to use one of the native Android or iOS frontend clients available in their respective stores (I recommend [Tusky](https://tuskyapp.github.io/) on Android).
+ **Toot** - A microblog entry on Mastodon, or the act of creating such an entry. On Pleroma, the equivalent term is **post** ([apparently](https://social.wonderdome.net/notice/3913)).
+ **Boost** - A reshare of a toot or post by someone else. Unlike on the birdsite, Pleroma and Mastodon don't support comments with the reshares, which (IMHO) seems to help minimize the "look at the stupid thing this person said" factor.
+ **Content Warning** (aka **CW**) - A Content Warning is (typically) used to hide text behind a click-to-see control. They are very versatile, although not all front-ends support them the same way. Some people use CWs for everything, while others only use them for extreme circumstances (or not at all).

OK, so now that we've gotten that out of the way, how should you actually get started in the Fediverse?

<a href="#" class="topLink">[ Back to Top ]</a>

### Step 1: Get an account.

If you haven't been invited to join a specific instance and don't have a recommendation to go on (such as from a friend or associate), I'd suggest checking out [instances.social](https://instances.social/list), a website that lists a large number of Mastodon and Pleroma instances, many of which have open registrations. While most of the instances are considered "general use", some are organized around a specific theme or idea (like [motorcycles](https://motogp.space/), [socialism](https://toot.lu/), or *[Star Trek](https://tenforward.social/about)*).

<a href="#" class="topLink">[ Back to Top ]</a>

### Step 2: Post an Introduction.

Once you've got an account, you may find it easier to get followers if you post a brief message describing yourself, preferably including the `#introduction` hashtag somewhere within it.  

These kinds of messages tend to be more useful at first, so try to do one as soon as you can. If you're on a Mastodon instance, you may even be able to pin your status to your profile, so it is always one of the first things that anyone sees about you when they pull your profile up (as of this writing, Pleroma doesn't currently support pinned statuses).

<a href="#" class="topLink">[ Back to Top ]</a>

### Step 3: Follow people.

Now that you're signed up and posted an introduction, the next step is to start following others. So, how do you find people to follow? If you're signing up at a public instance (or even a private instance focused around some common interests or goals), you can start by viewing your instance's [Whole Known Network](https://pleroma.site/main/all) timeline. This timeline includes posts by people on that instance, as well as posts by the accounts that the people on that instance follow (for example, when you go to [mastodon.social](https://mastodon.social/), by default you'll see their Whole Known Network, consisting of every post from any account that's followed by at least one account on mastodon.social). Look for some posts that interest you, and follow the accounts that made those posts.

If you're having trouble finding accounts to follow, you can use [instances.social](https://instances.social/list) for that, too. Just scroll through the list looking for instances devoted to [topics that](https://gamemaking.social/) [interest you](https://webdev.network/), and follow some of the accounts that show up on their landing pages.

Once you start following some accounts, if you're on a Pleroma instance, you'll probably see some posts in your feed that were made by people that you don't follow, and you may wonder how they got there. These are posts that have actually been _boosted_ by someone in your feed, but the Pleroma front-end (by default) doesn't explicitly indicate this.

By the way, IMHO, this is one of the best aspects of the current version of the Fediverse: since there is no opaque [magic algorithm](http://www.slate.com/articles/technology/cover_story/2016/01/how_facebook_s_news_feed_algorithm_works.html) deciding for you what posts you should or shouldn't see, it's important to reshare the best of what you see in your feed, as *this makes the whole network better*.

One quick word of warning - because of the way that both Mastodon and Pleroma are setup, once you start following an account, you won't actually see anything in your feed until those accounts start posting new material. As a result, it may take a few hours before your feed is fully populated with content, so be patient.

<a href="#" class="topLink">[ Back to Top ]</a>

### Step 4: Converse

One of the things that I really like about the Fediverse is that it feels like the Twitter did back when I first joined in 2007: there aren't a ton of people (yet), almost no one has more than a few hundred followers (yet), and the businesses haven't taken over there (yet). But, unlike even the [birdsite](#birdsite) of yore, there is a much greater emphasis on community as opposed to the *performative* posts ("Look at me! Look at me!") that have dominated centralized social media for so long.

So, once you start following people, the final step is to start actually conversing with them: reply to their questions, post questions of your own, and send messages of support when appropriate. As I said before, the smaller community size makes the connections that much more compelling, and the number of Mastodon and Pleroma instances virtually guarantees that there will be at least some other people out there who are into the same things you are.

So, that's it. If you've followed the guide this far, you have now officially gotten started in the Fediverse. Where you go from here is up to you, and I hope you enjoy it as much as I do.

One last thing - if you liked this guide, and enjoy reading posts about the web, surveillance capitalism, and/or [cats](https://social.wonderdome.net/notice/17646), you might consider following me, [@eric at the Wonder Dome](https://social.wonderdome.net/users/eric).

And thanks for stopping by!

<a href="#" class="topLink">[ Back to Top ]</a>

_Now that you're a Fediverse whiz, you can either [check out Da Roolz for the Wonder Dome](./tos.html), or you can [go back to the front page](./index.html). You have the power!_
